<?php
if(!defined('PLX_ADMIN')) { exit; }

# Control du token du formulaire
plxToken::validateFormToken();

if(!empty($_POST)) {
	$digest = filter_input(INPUT_POST, 'digest', FILTER_SANITIZE_SPECIAL_CHARS);
	if(empty($_POST['digest']) or !in_array($digest, kzOtPHP::DIGESTS)) {
		$digest = kzOtPHP::DEFAULT_DIGEST;
	}
	$plxPlugin->setParam('digest', $digest, 'string');

	$digits = intval(filter_input(INPUT_POST, 'digits', FILTER_SANITIZE_NUMBER_INT));
	if($digits < 3 or $digits > 10) {
		$digits = 6;
	}
	$plxPlugin->setParam('digits', $digits, 'numeric');

	$pattern = '#^(' . implode('|', array_keys(kzOtPHP::QR_CODE_PROVIDERS)) . ')?$#';
	$qrcode_provider = filter_input(INPUT_POST, 'qrcode_provider', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => $pattern)));

	if(!empty($qrcode_provider)) {
		$plxPlugin->setParam('qrcode_provider', $qrcode_provider, 'string');
	} else {
		$plxPlugin->delParam('qrcode_provider');
	}

	$plxPlugin->saveParams();
	header('Location: parametres_plugin.php?p=' . $plugin);
	exit;
}

$digits = intval($plxPlugin->getParam('digits'));
if($digits < 3 or $digits > 10) {
	$digits = 6;
}
$digest = $plxPlugin->getParam('digest');
if(!in_array($digest, kzOtPHP::DIGESTS)) {
	$digest = kzOtPHP::DEFAULT_DIGEST;
}
$qrcode_provider = $plxPlugin->getParam('qrcode_provider');
if(!empty($qrcode_provider) and !array_key_exists($qrcode_provider, kzOtPHP::QR_CODE_PROVIDERS)) {
	$qrcode_provider = '';
}
?>
<form method="post" class="inline-form" id="form_<?= $plugin; ?>">
	<div>
		<label for="id_digest"><?php $plxPlugin->lang('DIGEST'); ?></label>
		<select name="digest" id="id_digest">
<?php
foreach(kzOtPHP::DIGESTS as $value) {
	$selected = ($value == $digest) ? ' selected' : '';
?>
			<option value="<?= $value ?>"<?= $selected ?>><?= $value ?></option>
<?php
}

$providers = array(
	'' => $plxPlugin->getLang('LOCAL_SERVER'),
);
foreach(array_keys(kzOtPHP::QR_CODE_PROVIDERS) as $k) {
	$providers[$k] =$k;
}
?>
		</select>
	</div>
	<div>
		<label for="id_digits"><?php $plxPlugin->lang('DIGITS'); ?></label>
		<input type="number" name="digits" id="id_digits" value="<?= $digits; ?>" min="3" max="10" />
	</div>
	<div>
		<label for ="id_qrcode_provider"><?php $plxPlugin->lang('QRCODE_PROVIDER'); ?></label>
<?php plxUtils::printSelect('qrcode_provider', $providers, $qrcode_provider); ?>
	</div>
	<div class="in-action-bar">
		<?= plxToken::getTokenPostMethod(); ?>
		<input type="submit" value="<?= L_ARTICLE_UPDATE_BUTTON; ?>"/>
	</div>
</form>
<p><?php $plxPlugin->lang('APP_FOR_PINCODE'); ?> :</p>
<ul class="kzOtPHP-apps unstyled-list">
<?php
foreach(kzOtPHP::APPS as $store=>$infos) {
?>
	<li class="grid">
		<p class="col med-2 text-center"><a href="<?= $infos['searchUrl'] ?>" title="<?=$store ?>" target="kzOtPHP-store-<?= $store ?>" rel="noreferrer nofollow"><img src="<?= kzOtPHP::LOGOS_ROOT . $infos['logo'] ?>" /></a></p>
		<ul class="col med-10 inline-list">
<?php
	foreach($infos['apps'] as $name=>$url) {
		$url = $infos['storeUrl'] . $url;
		$src = kzOtPHP::LOGOS_ROOT . '100/' . strtolower($name) . '.png';
?>
			<li>
				<figure>
					<a href="<?= $url ?>" rel="noreferrer nofollow" target="kzOtPHP-app-<?= $name ?>"><img src="<?= $src ?>" alt="<?= $name ?>" /></a>
					<figcaption class="text-center"><?= str_replace('_', ' ', $name) ?></figcaption>
				</figure>
			</li>
<?php
	}
?>
		</ul>
	</li>
<?php
}
?>
</ul>
