<?php
# https://github.com/Spomky-Labs/otphp/blob/10.0.x/doc/index.md

const TITLE_PAGE = 'Test Spomky-Labs';
const IMG_SIZE = 300;
const QR_CODE_PROVIDERS = array(
	'QR Server'		=> 'https://api.qrserver.com/v1/create-qr-code/?bgcolor=fff&data=[DATA]&qzone=2&margin=0&size=' . IMG_SIZE . 'x' . IMG_SIZE . '&ecc=M',
	'QRickit'		=> 'https://qrickit.com/api/qr.php?d=[DATA]&qrsize=' . IMG_SIZE,
	'QuickChart'	=> 'https://quickchart.io/qr?text=[DATA]&size=' . IMG_SIZE, # https://quickchart.io/documentation/qr-codes/
);


require 'vendor/autoload.php';

use OTPHP\TOTP;

$totp = TOTP::create();
$totp->setIssuer(TITLE_PAGE);
$secret = $totp->getSecret();
$totp->setLabel('alice@wonderland.com');

# On récupère le texte à afficher dans le QRCode
$provisioningUri = $totp->getProvisioningUri();

# On récupère l'image du QRCode chez différents générateurs en ligne :
$qrserver = $totp->getQrCodeUri('https://api.qrserver.com/v1/create-qr-code/?bgcolor=fff&data=[DATA]&qzone=2&margin=0&size=' . IMG_SIZE . 'x' . IMG_SIZE . '&ecc=M', '[DATA]');
$qrickit = $totp->getQrCodeUri('https://qrickit.com/api/qr.php?d=[DATA]&qrsize=' . IMG_SIZE, '[DATA]');

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
	<title><?= TITLE_PAGE; ?></title>
	<meta http-equiv="content-type" content="text/html;charset=utf-8" />
	<style>
		#qrcodes {
			display: flex;
			overflow-x: auto;
			padding-bottom: 1rem;
		}
		figure { margin: 0 0.5rem; }
		figcaption { text-align: center; }
		#algorithms {
			display: flex;
			gap: 0.5rem;
			flex-wrap: wrap;
			justify-content: space-around;
			list-style: none;
			padding: 0 1rem;
		}
		#algorithms li {
			margin: 0;
			padding: 0.25rem 0.5rem;
			background-color: #eee;
		}
	</style>
</head>
<body>
<p>Most applications on smartphones only support md5, sha1, sha256 and sha512 (FreeOTP, Sophos Authentificator, ...).</p>
<pre>
Digits in use : <?= $totp->getDigits() . PHP_EOL ?>
Digest : <?= $totp->getDigest() . PHP_EOL ?>
The secret is <?= $secret . PHP_EOL ?>
The current OTP is : <?= $totp->now() . PHP_EOL ?>
The provisioningUri is : <?= $provisioningUri . PHP_EOL ?>
Label : <?= $totp->getLabel() . PHP_EOL ?>
</pre>
<div id="qrcodes">
<?php
foreach(QR_CODE_PROVIDERS as $name=>$pattern) {
	$src = $totp->getQrCodeUri($pattern, '[DATA]');
?>
	<figure>
		<img src="<?= $src ?>" alt="qrcode" width="<?= IMG_SIZE ?>" height="<?= IMG_SIZE ?>" />
		<figcaption><?= $name ?></figcaption>
	</figure>
<?php
}

/* *********************************** *\
 *    Générateur interne de QR code
 * *********************************** */

# internal QR-Code builder
use BaconQrCode\Renderer\ImageRenderer;
# use BaconQrCode\Renderer\Image\ImagickImageBackEnd;
use BaconQrCode\Renderer\Image\SvgImageBackEnd;
use BaconQrCode\Renderer\RendererStyle\RendererStyle;
use BaconQrCode\Writer;

$renderer = new ImageRenderer(
	new RendererStyle(IMG_SIZE),
	new SvgImageBackEnd()
);

# $renderer = new GDLibRenderer(IMG_SIZE);

$writer = new Writer($renderer);
$xml = $writer->writeString($provisioningUri);
# On supprime l'entête XML
$imgData = preg_replace('#^<\?xml [^>]*>\s*#', '', $xml);

?>
	<figure>
		<img src="data:image/svg+xml,<?= rawurlencode($imgData) ?>" alt="qrcode" width="<?= IMG_SIZE ?>" height="<?= IMG_SIZE ?>" />
		<figcaption>Internal builder (<em>SVG format)</em></figcaption>
	</figure>
</div>
<p>List of registered hashing algorithms :</p>
<ul id="algorithms">
<?php
foreach(hash_algos() as $v) {
?>
	<li><?= $v ?></li>
<?php
}
?>
</ul>
</body>
</html>
